## @knitr load-library
library(xxm)

## @knitr prepare-xxm-datasets
attach("nlsem.srm.xxm.RData");

## @knitr construct-R-matrices
# Within matrices for A(B) and B(A)
theta_wn_pat <- matrix(1,2,2)
theta_wn_val <- diag(3,2)
theta_wn_lab <- matrix(c("like_like","like_warm","like_warm", "warm_warm"),2,2)

nu_pat <- matrix(1,2,1)
nu_val <- matrix(6,2,1)
nu_lab <- matrix(c("like_mean", "warm_mean"),2,1)  

#Note: The use of common labels for nu (nu_lab) and theta (theta_wn_lab) 
#     for A(B) and B(A) imposes equality constraints on corresponding parameter estimates.

# Within latent covariance matrix for target
target_psi_pat <- matrix(1,2,2)
target_psi_val <- diag(.1,2)
# Within latent covariance matrix for rater
rater_psi_pat <- matrix(1,2,2)
rater_psi_val <- diag(.1,2)

# Across level dyadic residual-covaraince (A_B with B_A)
theta_bw_pat <- matrix(1,2,2)
theta_bw_val <- diag(0,2)
theta_bw_lab <- matrix(c("like1_like2","like1_warm2","like1_warm2", "warm1_warm2"))
#Note: The use of common labels like1_warm2 imposes equality constraints on 
#     across-level [A(B) and B(A)] covariance between `like` and `warm`.

# Across level Target-Rater covariance
rater_target_psi_pat <- matrix(1,2,2)
rater_target_psi_val <- matrix(0,2,2)

# Across-level factor loadings are all (2x2) identity matrices
lambda_pat <- matrix(0,2,2)
lambda_val <- diag(1,2)

## @knitr xxmModel
zz <- xxmModel(c("a_b","b_a", "target", "rater")) 

## @knitr xxmVirtual
alias = list(person = c("target", "rater"), dyad = c("a_b","b_a"))
zz <- xxmVirtuals(zz,alias);
zz <- xxmVirtualids(zz,person)
zz <- xxmVirtualids(zz,dyad)

## @knitr xxmSubmodel
#Level 1: A(B)
zz <- xxmSubmodel(model = zz, level = "a_b", parents = c("target", "rater"),
                  ys = c("like", "warm"), xs =, etas =, data = A_B,)

#Level 1: B(A)
zz <- xxmSubmodel(model = zz, level = "b_a", parents = c("target","rater"), 
                  ys = c("like", "warm"), xs = , etas =, data = B_A,) 

#Level 3: Target
zz <- xxmSubmodel(model = zz, level = "target", parents = ,
                  ys =,xs =, etas = c("like-target", "warm-target"), data = target,)

#Level 3: Rater
zz <- xxmSubmodel(model = zz, level = "rater", parents = , 
                  ys=,xs=, etas = c("like-rater", "warm-rater"), data = rater,)

## @ knitr xxmWithinMatrix
#Level 1: A_B :: Intercepts
zz <- xxmWithinMatrix(model = zz, level = "a_b",type = "nu", 
                      pattern = nu_pat, value = nu_val, label = nu_lab,name = )
#Level 1: A_B :: Residual-covariance
zz <- xxmWithinMatrix(model = zz, level = "a_b","theta", 
                      pattern = theta_wn_pat, value = theta_wn_val, label = theta_wn_lab,) 
#Level 2: B_A :: Intercepts
zz <- xxmWithinMatrix(model = zz, level = "b_a", type = "nu", 
                      pattern = nu_pat, value = nu_val, label = nu_lab,)
#Level 2: B_A :: Residual-covariance
zz <- xxmWithinMatrix(model = zz, level = "b_a", type = "theta",  
                      pattern = theta_wn_pat, value = theta_wn_val, label = theta_wn_lab,) 
#Level 3: Target
zz <- xxmWithinMatrix(model = zz, level = "target", type = "psi", 
                      pattern = target_psi_pat, value = target_psi_val,,)
#Level 4: Rater
zz <- xxmWithinMatrix(model = zz, level = "rater", type = "psi", 
                      pattern = rater_psi_pat, value = rater_psi_val,,)
## @ knitr xxmBetweenMatrix
### A(B)-B(A) residual covariance
zz <- xxmBetweenMatrix(model = zz, parent = "b_a",  child = "a_b", type = "theta", 
                       pattern = theta_bw_pat, value = theta_bw_val, label = theta_bw_lab,)
### Target-Rater covariance
zz <- xxmBetweenMatrix(model = zz, parent = "rater", child = "target", type = "psi", 
                        pattern = rater_target_psi_pat, value = rater_target_psi_val,,)
# Target -> A_B link matrix:
zz <- xxmBetweenMatrix(model = zz, parent = "target", child = "a_b", type = "lambda",
                       pattern =  lambda_pat, value = lambda_val, label = )
# Target -> A_B link matrix:
zz <- xxmBetweenMatrix(model = zz, parent = "target", child = "b_a", type = "lambda",
                       pattern = lambda_pat, value = lambda_val, label = )
# Rater -> A_B link matrix:
zz <- xxmBetweenMatrix(model = zz, parent = "rater", child = "a_b", type = "lambda", 
                       pattern = lambda_pat, value = lambda_val, label = )
# Rater -> B_A link matrix:
zz <- xxmBetweenMatrix(model = zz, parent = "rater", child = "b_a", type = "lambda", 
                       pattern = lambda_pat, value = lambda_val, label = )

## @knitr xxmRun
zz <- xxmRun(zz)
## @knitr xxmCI
zz <- xxmCI(zz)
## @knitr xxmSummary
bivariate.srm.results <- xxmSummary(zz)
bivariate.srm.results 
## @knitr xxmFree
zz <- xxmFree(zz) 
rm(list = ls())   